==> jmb.news-0.1.tar.gz: jmb.news-0.1/jmb/news/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from jmb.core.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.news.models import News, Category, NewsTranslation


class CategoryAdminForm(AdminModelForm):
    class Meta:
        model = Category


class CategoryAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon', 'name', 'slug','get_edit_icon', 'get_delete_icon')
    list_display_links = ('name',)
    prepopulated_fields = {"slug": ("name",)}
    model = Category
    save_on_top = True
    form = CategoryAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering", "name",)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': (
                'collapse',
            )
        }),
        (_('visualization admin'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {
            'fields': ('status',),
        }),
        (None, {"fields": ("name","slug"),}),
    )

admin.site.register(Category, CategoryAdmin)


class NewsInlineModelForm(AdminModelForm):
    class Meta:
        model = NewsTranslation


class NewsInline(admin.StackedInline):
    model = NewsTranslation
    form = NewsInlineModelForm
    extra = 3
    fields = ( 'language', 'title', 'short_description',)


class NewsAdminForm(AdminModelForm):
    class Meta:
        model = News


class NewsAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    model = News
    save_on_top = True
    form = NewsAdminForm
    list_display = (
        'get_status_icon', 'title', 'event_date',
        'pub_date_begin', 'pub_date_end', 'get_categories', 'get_users',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_links = ('title',)
    #list_filter = ("status", "type",'event_date','pub_date_begin','pub_date_end',)
    search_fields = ('title', 'event_date', 'pub_date_begin', 'pub_date_end',)
    list_per_page = 30
    ordering = ("ordering","title")
    prepopulated_fields = {"slug": ("title",)}
    fieldsets = (
        (_('logs admin'),{
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('Ordering'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (None, {
            'fields': ('status', 'categories',),
        }),
        (None, {
            "fields": (
                'title','slug','event_date',
                'small_image', 'big_image',
                'short_description', 'full_description',
                'link', 'file', 'note',
            ),
        }),
        (_('Publication date'), {
            'fields': ('pub_date_begin', 'pub_date_end',),
            'classes': ('collapse',),
        }),
        (_('Show to'), {
            'fields': ('users',),
        }),
    )

    filter_horizontal = ('users', 'categories',)
    inlines = (NewsInline,)


class NewsTranslationInline(admin.StackedInline):
    model = NewsTranslation
    extra = 0
    fieldsets =  (None,{
        'classes': ('collapse',),
        'fields': (
            'language', 'name', 'short_description',
            'full_description',
            )
    }),

admin.site.register(News, NewsAdmin)

#
#
#class NewsCategoryTranslationInline(admin.StackedInline):
#    model = NewsCategoryTranslation
#    extra = 0
#    fields = ('language', 'name', 'short_description', 'full_description',)
#
#
#class NewsImageInline(admin.StackedInline):
#    model = NewsGalleryImage
#    fields = ['title', 'image', 'status']
#    extra = 1
#
#
#class NewsCategoryImageInline(admin.StackedInline):
#    model = NewsCategoryGalleryImage
#    fields = ['title', 'image', 'status']
#    extra = 1


#class NewsAdmin(admin.ModelAdmin):
#    prepopulated_fields = {"slug": ("name",)}
#    fieldsets = (
#        ('Advanced options', {
#            'classes': ('collapse',),
#            'fields': (
#                'creator', 'date_create', 'last_modifier',
#                'date_last_modify', 'ordering'
#                )
#        }),
#        (None, {
#            'fields': (
#                'status',
#                'name', 'slug', 'date', 'short_description',
#                'full_description', 'categories',
#                'related_news',
#                )
#        }),
#        )
#    list_display_links = ('name',)
#    list_display = ('status', 'name', 'date', 'list_categories', 'slug', 'short_description', 'ordering',)
#    list_editable = ('ordering', 'status', 'date',)
#    ordering = ('name',)
#    filter_horizontal = ('categories', 'related_news',)
#    inlines = (NewsImageInline, NewsTranslationInline)
#
#    save_on_top = True
#
#    def list_categories(self, obj):
#        """
#        restituisce la lista delle categorie associate
#        """
#        list_categories = []
#        categories = obj.categories.filter(status=1)
#        for category in categories:
#            list_categories.append(category.name)
#        return ",".join(list_categories)
#
#    list_categories.short_description = "categories"
#
#
#class NewsCategoryAdmin(MPTTModelAdmin):
#    prepopulated_fields = {"slug": ("name",)}
#    fieldsets = (
#        ('Advanced options', {
#            'classes': ('collapse',),
#            'fields': (
#                'creator', 'date_create', 'last_modifier',
#                'date_last_modify', 'ordering')
#        }),
#        (None, {
#            'fields': (
#                'parent', 'name', 'slug', 'short_description',
#                'status', 'full_description',
#                )
#        }),
#        )
#
#    list_display_links = ('name',)
#    list_display = ('status', 'name', 'slug', 'short_description', 'ordering')
#    list_editable = ('ordering', 'status',)
#
#    inlines = (NewsCategoryImageInline, NewsCategoryTranslationInline,)
#    save_on_top = True
#
#
#admin.site.register(News, NewsAdmin)
#admin.site.register(NewsCategory, NewsCategoryAdmin)

==> jmb.news-0.1.3.tar.gz: jmb.news-0.1.3/jmb/news/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from jmb.core.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.news.models import News, Category, NewsTranslation


class CategoryAdminForm(AdminModelForm):
    class Meta:
        model = Category


class CategoryAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon', 'name', 'slug',)
    list_display_links = ('name',)
    prepopulated_fields = {"slug": ("name",)}
    model = Category
    save_on_top = True
    form = CategoryAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering", "name",)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': (
                'collapse',
            )
        }),
        (_('Ordering'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {
            'fields': ('status',),
        }),
        (None, {"fields": ("name","slug"),}),
    )

admin.site.register(Category, CategoryAdmin)


class NewsInlineModelForm(AdminModelForm):
    class Meta:
        model = NewsTranslation


class NewsTranslationInline(admin.StackedInline):
    model = NewsTranslation
    extra = 0
    prepopulated_fields = {"slug": ("title",)}
    fieldsets = (
        (None, {
            'fields': (
                'language','title','slug',
                'short_description','full_description'
                )
        }),
        )


class NewsAdminForm(AdminModelForm):
    class Meta:
        model = News


class NewsAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    model = News
    save_on_top = True
    form = NewsAdminForm
    list_display = (
        'get_status_icon','title','event_date',
        'get_categories', 'get_users',
        'get_edit_icon','get_delete_icon',
    )
    list_display_links = ('title',)
    #list_filter = ("status", "type",'event_date','pub_date_begin','pub_date_end',)
    list_per_page = 30
    ordering = ("ordering","title",)
    ordering = ("categories",)
    prepopulated_fields = {"slug": ("title",)}
    fieldsets = (
        (_('logs admin'),{
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('Ordering'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (None, {
            'fields': ('status', 'categories',),
        }),
        (None, {
            "fields": (
                'title','slug',
                'event_date','show_date_in_detail_page',
                'small_image', 'big_image',
                'short_description', 'full_description',
                'link', 'file', 'note',
            ),
        }),
        (_('Publication date'), {
            'fields': ('pub_date_begin', 'pub_date_end',),
            'classes': ('collapse',),
        }),
        (_("SEO settings"), {
            'fields' : ('page_title','meta_description','meta_keywords'),
            'classes': ('collapse',)
        }),
        (_('Show to'), {
            'fields': ('users',),
        }),
    )
    advanced_search_fields = (
        ('title__icontains',),
        ('categories__in',),
    )

    filter_horizontal = ('users', 'categories',)
    inlines = (NewsTranslationInline,)


admin.site.register(News, NewsAdmin)

#
#
#class NewsCategoryTranslationInline(admin.StackedInline):
#    model = NewsCategoryTranslation
#    extra = 0
#    fields = ('language', 'name', 'short_description', 'full_description',)
#
#
#class NewsImageInline(admin.StackedInline):
#    model = NewsGalleryImage
#    fields = ['title', 'image', 'status']
#    extra = 1
#
#
#class NewsCategoryImageInline(admin.StackedInline):
#    model = NewsCategoryGalleryImage
#    fields = ['title', 'image', 'status']
#    extra = 1


#class NewsAdmin(admin.ModelAdmin):
#    prepopulated_fields = {"slug": ("name",)}
#    fieldsets = (
#        ('Advanced options', {
#            'classes': ('collapse',),
#            'fields': (
#                'creator', 'date_create', 'last_modifier',
#                'date_last_modify', 'ordering'
#                )
#        }),
#        (None, {
#            'fields': (
#                'status',
#                'name', 'slug', 'date', 'short_description',
#                'full_description', 'categories',
#                'related_news',
#                )
#        }),
#        )
#    list_display_links = ('name',)
#    list_display = ('status', 'name', 'date', 'list_categories', 'slug', 'short_description', 'ordering',)
#    list_editable = ('ordering', 'status', 'date',)
#    ordering = ('name',)
#    filter_horizontal = ('categories', 'related_news',)
#    inlines = (NewsImageInline, NewsTranslationInline)
#
#    save_on_top = True
#
#    def list_categories(self, obj):
#        """
#        restituisce la lista delle categorie associate
#        """
#        list_categories = []
#        categories = obj.categories.filter(status=1)
#        for category in categories:
#            list_categories.append(category.name)
#        return ",".join(list_categories)
#
#    list_categories.short_description = "categories"
#
#
#class NewsCategoryAdmin(MPTTModelAdmin):
#    prepopulated_fields = {"slug": ("name",)}
#    fieldsets = (
#        ('Advanced options', {
#            'classes': ('collapse',),
#            'fields': (
#                'creator', 'date_create', 'last_modifier',
#                'date_last_modify', 'ordering')
#        }),
#        (None, {
#            'fields': (
#                'parent', 'name', 'slug', 'short_description',
#                'status', 'full_description',
#                )
#        }),
#        )
#
#    list_display_links = ('name',)
#    list_display = ('status', 'name', 'slug', 'short_description', 'ordering')
#    list_editable = ('ordering', 'status',)
#
#    inlines = (NewsCategoryImageInline, NewsCategoryTranslationInline,)
#    save_on_top = True
#
#
#admin.site.register(News, NewsAdmin)
#admin.site.register(NewsCategory, NewsCategoryAdmin)
